#
# spec file for package pcsx2
#
# Copyright (c) 2018 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#

Name:           pcsx2
Version:        1.5.0~git20181020
Release:        1.3
Summary:        Sony PlayStation 2 Emulator
Group:          System/Emulators/Other
License:        LGPL-3.0
URL:            http://pcsx2.net/
Source:         %{name}-%{version}.tar.xz

BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libaio-devel
BuildRequires:  libaio1
BuildRequires:  wxWidgets-3_0-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(soundtouch)
BuildRequires:  pkgconfig(x11)
ExclusiveArch:  i586

%description
Sony PlayStation 2 emulator. Requires a BIOS image in %{_libdir}/%{name}/bios
or in .%{name}/bios in your HOME directory (will be created when you first run
PCSX2). Check http://www.pcsx2.net/guide.php#Bios for details on which files
you need and how to obtain them.

%prep
%setup -q

#Avoid fatal cmake error when it cannot find sdl2 for onepad
sed -i 's|print_dep("Skip build of onepad: miss some dependencies" "${msg_dep_onepad}")||g' cmake/SelectPcsx2Plugins.cmake

%build
%cmake .. \
  -DCMAKE_BUILD_TYPE='Release' \
  -DUSER_CMAKE_C_FLAGS='%{optflags} -Wno-narrowing' \
  -DUSER_CMAKE_CXX_FLAGS='%{optflags} -Wno-narrowing' \
  -DPLUGIN_DIR='%{_libdir}/%{name}' \
  -DGAMEINDEX_DIR='%{_datadir}/%{name}' \
  -DDOC_DIR='%{_datadir}/doc/%{name}' \
  -DBIN_DIR='%{_bindir}' \
  -DXDG_STD='TRUE' \
  -DDISABLE_PCSX2_WRAPPER='TRUE' \
  -DPACKAGE_MODE='TRUE' \
  -DDISABLE_ADVANCE_SIMD='TRUE' \
  -DDISABLE_BUILD_DATE='TRUE' \
  -DGSDX_LEGACY='TRUE' \
  -DSDL2_API='TRUE'

%make_jobs

%install
%cmake_install

# move translations to main language dir if there isn't a sublang or delete
# translations not supported by distro at all
for i in $(ls %{buildroot}%{_datadir}/locale | grep _); do
  new=$(echo $i | sed "s:_.*::g")
  if [ ! -d %{_datadir}/locale/$i ]; then
    if [ -d %{_datadir}/locale/$new ]; then
      mv %{buildroot}%{_datadir}/locale/$i %{buildroot}%{_datadir}/locale/$new
    else
      rm -rf %{buildroot}%{_datadir}/locale/$i
    fi
  fi
done

%fdupes -s %{buildroot}
%find_lang %{name}_Main
%find_lang %{name}_Iconized

%check
%ctest

%files -f %{name}_Main.lang -f %{name}_Iconized.lang
%doc README.md
%license COPYING.LGPLv2.1 COPYING.LGPLv3 COPYING.GPLv2 COPYING.GPLv3
%{_bindir}/PCSX2
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/doc/%{name}
%{_datadir}/applications/PCSX2.desktop
%{_datadir}/pixmaps/PCSX2.xpm
%{_mandir}/man1/PCSX2.1%{?ext_man}

%changelog
* Thu Oct 25 2018 hillwood@opensuse.org
- Update to version 1.5.0~git20181023:
  * GSdx: Add an enum for channel fetch.
  * pcsx2-gui: Align some of the buttons/options in GS Window.
* Mon Oct 22 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181020:
  * GSdx-d3d: SetupDATE - > use pretty enum names.
  * GSdx: Add Harry Potter and the Half-Blood Prince to automatic mipmapping.
* Fri Oct 19 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181019:
  * GSdx-d3d: Add macro to support ScalingFactor in shaders.
  * GSdx-d3d: Partial port of the ICO HLE workaround.
  * GSdx: Revert disabled crc hack on native res for SFEX3.
  * GameDB: Add GIFFIFOHack to Mana Khemia 1 and 2.
  * GSdx-d3d: Move around some functions in DrawPrims to better match ogl.
* Wed Oct 17 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181016:
  * GSdx-gui: Change internal resolution drop down list names.
  * Reenable the new saveslots. Disable the logging for them.
  * Revert "Saveslots: This version is still commented out, and somewhat broken at the moment. If you uncomment it, after loading a game, pause and then resume to force the save and load menus to update."
  * pcsx2: small string typo fix.
* Mon Oct 15 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181015:
  * GSdx: Change how crc hacks work on native res.
  * SPU2-X: Adjust NextA case comments a bit.
* Mon Oct 15 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181015:
  * SPU2-X: Also include the registers from case 5 since it makes more sense to have both NextA writable.
  * SPU2-X: Fixes a regression with Wallace And Gromit: Curse Of The Were-Rabbit sound cutting off.
  * PCSX2: Add tooltip warning for Widescreen Patches.
  * Dev9ghzdrk: Postinst for deb to add network capabilities
* Sun Oct 14 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181014:
  * Saveslots: This version is still commented out, and somewhat broken at the moment. If you uncomment it, after loading a game, pause and then resume to force the save and load menus to update.
  * Add some logging for the saveslot changes, and the option to turn on just the extra ui update calls without the other saveslot changes, for testing.
  * A few more flags that slipped by the last commits.
  * Removing some warnings from GSdx and pcsx2 because gcc 8 spams them mercilessly. They should probably be fixed properly, but in the meantime, this'll prevent them from masking other compiler warnings.
  * PCSX2: update of Scandinavian translations
  * Update compiler flags, as a number of plugins didn't have them set. Setting -Wno-parentheses across the board to suppress warnings about gtk from gcc 8.
* Sat Oct 13 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181012:
  * onepad_legacy: Separate the wx dialog code from the linux code here, too.
  * onepad: Start to separate wx dialog code from linux code, as wxWidgets is multiplatform.
* Fri Oct 12 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181010:
  * PCSX2: GUI textstring corrections
  * GSdx-gui: Forgot to update the buttons in Capture Settings.
  * GSdx-gui: Minor spacing changes to some buttons.
* Wed Oct 10 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181009:
  * Onepad_legacy: Add missing header copyright notices.
  * Remove the -fpermissive flag, as it doesn't actually seem necessary, and it generates a compiler warning.
  * Dev9ghzdrk: Get host mac correctly on Windows. (#2619)
  * GSdx-d3d: 24bit no alpha channel port from OpenGL.
  * GameDB: Add patches for Ice Age 2 to make the games playable.(ntscu and pal).
  * glsl, fx: Update point sampler comment.
  * GSdx-d3d: Use a pretty enum for ate_second_pass.
  * GSdx-d3d: Remove point sampler from d3d9.
  * GSdx-d3d: Use Colormask instead of GSDXRecoverableError on d3d9 texture shuffle.
  * PCSX2: Added complete Dutch translations. (#2625)
  * Fix
  * Enable dev9ghzdrk plugin for Linux build
  * GSdx-d3d: Reformat GSRendererDX11.cpp.
  * GSdx-d3d: Port directly set impossible mode in the blending table from OpenGL.
* Sun Oct  7 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181006:
  * onepad_legacy: delete dead code.
  * onepad_legacy: reformat code.
  * Onepad-legacy: Even if std is used all over the place, lets not put the entire project in std's namespace.
* Sat Oct  6 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181006:
  * GSdx-d3d: Add some comments in blendmap enums.
  * GSdx-d3d: Make blend enums easier to read.
  * Redo how the saveslot code works. Still leaving disabled until it's been tested.
  * Update Onepad's controller list.
* Fri Oct  5 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181005:
  * GSdx-d3d: optimize colclip 0 port from OpenGL.
  * pcsx2: Update some redirect links.
  * glsl: remove signed int cast  side (masks and offsets are unsigned to begin with.
  * Update Travis CI for Linux networking addition
  * GSdx-d3d: Change DATE variable to local.
* Wed Oct  3 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181003:
  * GSdx-gui: Adjust space/rows on some tooltips so they fit better, rename Auto to Automatic list on adv. gl settings in hw hacks.
  * tfx.fs: Remove whitespaces.
  * GSdx: Limit Wrap negative UV when PS_FST is 0 only.
  * Add network capability for Linux (#2586)
  * GSdx-d3d: Add colclip_wrap variable.
  * GSdx-d3d: purge GSDrawingContext* context and GSDrawingEnvironment env from GSRendererDX.h
* Tue Oct  2 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20181002:
  * New helper include for gtk for use in plugins. Mostly based on the gtk 2/3 helper functions I added to spu2-x for the moment.
  * GSdx-d3d: Reformat GSRendererDX.cpp.
  * GSdx: Add a crc id for Burnout Revenge EU.
  * GSdx-gui: Remove Xenosaga tooltip from TC Offset hack.
  * GSdx: Wrap negative UV on region repeat wrap mode.
  * Disable the new saveslot code. (It can be reenabled by uncommenting the define in Saveslots.h)
  * Make it easy to turn on and off the new saveslot code. Comment out a UI update that doesn't look needed that could have been causing issues.
* Sat Sep 29 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180928:
  * GSdx-d3d: Keep fract in [0;1] range port from OpenGL.
* Wed Sep 26 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180926:
  * GameDB: Add VU Clamp Mode and GIF FIFO Hack to SOCOM 1. Resolves bad shadows/random HUD and sprite corruption.
* Tue Sep 25 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180925:
  * GSdx-d3d: Update nvidia hack with vendor id detection.
  * GSdx-d3d: Port mipmap max_layer calculation from opengl to direct3d.
* Sun Sep 23 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180923:
  * PCSX2: update of Scandinavian translations
* Thu Sep 20 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180920:
  * gsdx: Split TC offset hack into X and Y components
  * gsdx:hw: Move TC offset variables to GSRendererHW
* Tue Sep 18 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180917:
  * GSdx-d3d: tfx.fx correct texture shuffle shaders.
  * pcsx2: Warn if GameDB section start tag is incorrect
  * pcsx2: Improve GameDB multiline section parsing
  * GSdx-d3d: Mask alpha channel on 24bit format.
  * Remove an extern that goes to a function not in the code.
  * Restore wxInvalidDateTime, and fix the call that was crashing debug.
  * GSdx-tc: Update fb conversion hack comment with latest d3d changes.
* Sat Sep 15 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180915:
  * Using wxInvalidDatetime does not get along with debug builds. Using 1/1/1970 instead.
  * GSdx-d3d: Move Selector reset states in to a separate function.
* Thu Sep 13 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180913:
  * GSdx: GPU accelerate 8 bits texture conversion port from OpenGL to Direct3D11.
  * GSdx-gui: Minor osd gui adjustments.
* Wed Sep 12 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180912:
  * GSdx: Add Yakuza ntsc-u demo crc id.
  * PCSX2: Save/load slot improvements.
  * build.sh: correct some tab/space issues left by arcum from previous commit.
* Thu Sep  6 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180905:
  * Add a new option to build.sh to not generate translations while building the project.
* Wed Sep  5 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180904:
  * pcsx2|utilities; Revert ambiguous wxString related commits
  * Missed some more code from testing. I do know what I'm doing I swear
  * Missed a debug log.
  * Reverted shift register stuff back to how it was, my changes made no difference now and it was slightly more optimal before. Also fixed spaces (blame PSI :P )
  * Fixed MFSA/MTSA, of course there's a game that abuses it (Rayman 3)
* Tue Sep  4 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180903:
  * utilities: Fix compile when using --enable-stl wxWidgets builds
  * utilities: Split thread internal callback function
  * SPU2-X-gui: Small corrections requested by turtleli.
  * GSdx-gui: Minor adjustements.
* Mon Sep  3 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180903:
  * SPU2-X: More gui adjustements.
  * GSdx: GSHwHack.cpp adjust a few lines I forgot in the previous commit.
  * GSdx: Adjust Yakuza games crc hacks and do some reformatting.
  * pcsx2|utilities: Remove ambiguous wxString-related overloads
* Sat Sep  1 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180901:
  * GSdx: Add Sly2 Internal prototype disc crc id.
  * Gamedb: Tidy up remaining tab spaces and some other cleaning.
  * Gamedb: Merge duplicate patches, the only difference is the crc id, the patch codes are the same.
  * GameDB: Remove trailing whitespace
  * debugger: Reset breakpoint skip on boot
  * pcsx2: Don't store the GameDB serial in the key list
  * pcsx2: Remove GameDB blocktable
  * utilities: Remove HashMap
  * pcsx2: Simplify GameDB hashing
  * pcsx2: Simplify Game_Data member functions
  * pcsx2: Remove GameDB write related code
  * GSdx-gui: Grey out Texture filtering and Interlacing on Null.
  * gsdx:windows: Show different adapters for each renderer
  * gsdx:windows: Don't refer to D3D10
  * gsdx:windows: Refactor D3D11/9 adapter enumeration code
  * gsdx:windows: Init hacks dialog member variables in constructor
  * gsdx:windows: Open sub dialogs using temporary objects
  * round count in constructor (to squash)
  * gsdx ogl: allow to reallocate the vertex/index buffer
  * gsdx ogl: use vector for layout parameter of Vertex Array
  * i10n: update pt_BR translation
* Tue Aug 28 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180827:
  * GSdx: Add some crc ids for HarryPotterATPOA KO/JP.
  * Gamedb: Add Harry Potter and The Prisoner of Azkaban KO/JP gamefix patches.
  * Gamedb: Correct misspelled SkipMPEGHack for Paris-Dakar Rally.
* Mon Aug 27 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180827:
  * glsl: Replace leftover tabs with spaces in shaderboost.
  * Add System Out as a logging source. (#2563)
  * pcsx2:gui: Remove Game Database dialog and panel
* Sun Aug 26 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180825:
  * SPU2-X (Linux): Lets try this again. GTK 3 fixes. Volume slider added. Latency slider shows ms. Debug button disables and reenables. Various dialog box tweaks.
* Sat Aug 25 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180825:
  * Rename VU Cycle stealing to EE Cycle Skipping, and change tool tips for EE Cycle Stealing and EE Cycle Skipping
  * ci: Disable clang-format checks on Travis CI
  * Revert my last couple commits because they don't meet a robot's code formatting standards.
  * Attempt to placate evil spirits.
  * Spu2-x(Linux): Debug button greys out when appropriate. Minor cleanup on last commit.
  * Spu2-X (Linux): Dialog cleanup. Add volume control. Switch Ok/Cancel buttons to be the same as other plugins on Linux. Add in code for GTK 3 to get rid of depreciation warnings.
* Fri Aug 24 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180824:
  * GSdx-gui: Don't disable Anisotropic Filtering on gl when Allow 8-bit textures is enabled.
* Thu Aug 23 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180822:
  * glsl: Replace leftover tabs with spaces in tfx_fs.
  * Gsdx: Point Sampler changes.
  * [skip ci] Update all links to https on README.md.
  * Translations: pt_BR: fix typo in pcsx2_Iconized.po (#2561)
  * Get rid of AppConfigDialog.cpp.
  * GSdx: Add Ape Escape 2 to automatic mipmapping.
  * GSdx-gui: Put TC Offset X Y hacks in one line similar to Skipdraw Offset
* Tue Aug 21 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180821:
  * GSdx-d3d: Reduce state change - port from GL.
  * GSdx-d3d: s/sample_4a/sample_4_index/
  * GSdx-d3d: Drop an useless min in FS - port from GL.
* Tue Aug 21 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180820:
  * gsdx:hw: Enable skipdraw hack to skip a range of draw calls
* Mon Aug 20 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180820:
  * GSdx-gui: Revert spacing between Texture filtering and Hardware settings.
  * GSdx-gui: Adjust main gui spacing.
  * Add the Logitech Rumble Gamepad F510 to onepad's database.
* Sat Aug 18 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180817:
  * Make the dialog for zzogl-pg GTK 3 compatible.
  * utilities: Restrict pxWindowAndFlag templates to wxObject derived classes
* Thu Aug 16 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180816:
  * cmake: Add -mxsave flag to compiler flags
* Sun Aug 12 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180812:
  * gsdx:gtk: Improve dialog for small screen resolutions
  * gsdx:gtk3: Fix fetching of monitor resolution
  * gsdx:gtk+3: Adjust visual layout
  * gsdx:gtk3: Switch to non-deprecated GTK3 API
  * common: Use GCC's _xgetbv definition from GCC 8.2 onwards
* Sun Aug 12 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180812:
  * GameDB: Add XgKickHack to Warhammer 40K. Fixes corrupted graphics.
  * Debugger: Display ACC register. (#2527)
* Fri Aug 10 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180809:
  * SPU2-X-gui: Update gui interface.
* Wed Aug  8 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180808:
  * spu2-x:gtk3: Fix hbox/vbox deprecation warnings
  * spu2-x:linux: Reduce non-timestretch minimum latency to 3ms
  * GSdx-gui: Properly grey out Anisotropic Filtering text when the option is inactive.
* Tue Aug  7 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180807:
  * GSdx-gui: Update CRC Hack Level tooltips.
  * gsdx:ogl: Remove unused variables
  * pcsx2: Avoid trigraphs
  * onepad|spu2-x: Avoid -Wmissing-braces on clang
  * pcsx2: Add override to SysTraceLog functions declarations/definitions
* Sat Aug  4 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180804:
  * GSdx: Adjust God of War II crc hack.
  * GameDB: Add eeClampMode gamefix to Destroy All Humans 2 (ntsc).
  * GameDB: Add EE and VU clamping mode gamefix for  A.C.E. 3 the final.
  * GSdx: Add/adjust crc ids.
* Wed Aug  1 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180801:
  * GSdx: Adjust ShinOnimusha crc hack. (#2521)
  * Grammar corrections in readme-Docs.txt (#2529)
  * GameDB: Add patches for Harry Potter (Chamber of Secrets, Prisoner of Azkaban).
  * Just adding some comments to MMI fix.
  * Corrected MMI PMADDW and PMSUBW on the Interpreters thanks to DobieStation for finding the fix
* Tue Jul 31 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180731:
  * GSdx: Add games to automatic mipmapping, add some crc ids.
  * GameDB: Conflict 4, K-1 WorldGP 2006 and Mahou Sensei Negima! Kagai Jugyou fixes.
* Mon Jul 30 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180730:
  * Debugger: Display/set correct VU values (#2526)
* Tue Jul 24 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180723:
  * GameDB: Apply EE Clamp gamefix to Kenran Butousai. Fixes missing graphics.
* Mon Jul 23 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180723:
  * pcsx2:windows: Fix path issues
  * spu2-x:linux: Fix ini path issue
  * gsdx:windows: Fix screenshot/GS dump path issues
  * misc-plugins:windows: Fix ini/log path issues
  * common: Add plugin compatibility file
  * dev9null|fwnull|usbnull:windows: Export *setLogDir
  * pcsx2: Pass UTF-8 pathnames to plugins
* Fri Jul 20 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180719:
  * GSdx: Adjust Spartan crc hack, add missing crc id. (#2510)
  * GSdx: Add Harry Potter Order of the Phoenix to automatic mipmapping.
  * GSdx: Add/adjust some CRC ids. (#2512)
* Tue Jul 17 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180715:
  * GSdx: Add some missing crc ids.
  * EE Rec/Int: Removed micro optimisation in QFSRV/MSTAB/MSTAH. Reverted functionality to match the documentation. There were some scenarios that weren't really accounted for, like developers doing what they're told not to do.
* Sun Jul 15 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180714:
  * MFIFO: Fix Tadr position on END tags with data. An Empty interrupt needs to be fired at DMA end for FF7 DoC, but the formula doesn't work out normally since we don't increment TADR on END tags (due to Soul Calibur 2 & 3 breaking), so a special case is made for MFIFO
* Fri Jul 13 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180712:
  * GameDB: Disable mVU Flag hack for Full Spectrum Warrior. Remove EE Timing hack from Full Spectrum Warrior games. (#2504)
  * GSdx: Adjust Kunoichi crc hack (#2502)
* Thu Jul 12 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180712:
  * dev9null|fwnull|usbnull: Switch to new null config code
  * common: Add common null plugin config code
  * dev9null|fwnull|usbnull:windows: Remove snprintf define
  * dev9null|fwnull|usbnull: Remove *About()
  * common: Remove PluginNullAbout
  * fwnull|usbnull: Remove unused Windows-specific stuff
* Tue Jul 10 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180709:
  * GameDB: Fix missing game board in Monopoly Party, add Gene Troopers
* Wed Jul  4 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180703:
  * GSdx: Add some missing crc ids. (#2498)
  * GameDB: Drakengard 2 fixes, Mvu flag fix for Full Spectrum Warrior and missing serials. (#2490)
  * GSdx: Adjust Ghost In The Shell SOC crc hack. (#2492)
* Sun Jul  1 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180701:
  * GSdx: Add crc id for Shadow of Rome Demo (NTSC-U).
  * GSdx: Add crc id for ICO Demo (NTSC-U).
  * GSdx: Add crc id for The Getaway Black Monday Demo (NTSC-U).
* Fri Jun 29 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180628:
  * IOP: VBlank handler small fix
* Thu Jun 28 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180627:
  * GameDB: Various patches update. (#2487)
* Wed Jun 27 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180627:
  * Counters: Fix vsync hsync cycles calculation for rounding error
  * GSdx: Add Nicktoons Unite to Automatic Mipmapping.
  * GSdx: Add crc id for The Getaway Black Monday (NTSC-J).
  * GSdx: Add crc id for Ratchet And Clank 3 Regular Demo (NTSC-U).
* Mon Jun 25 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180624:
  * GSdx: Add crc id for Ratchet & Clank 2: Going Commando & Jak II Demo disc (NTSC-U).
* Sat Jun 23 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180622:
  * ci: Update Travis CI configuration
  * common: Call va_end after vfprintf in PluginLog
* Thu Jun 21 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180620:
  * Mild improvement to VIF MFIFO logging, got rid of a useless global variable \o/
* Tue Jun 19 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180618:
  * GSdx: Add Sly 3 PAL demo crc id.
  * GameDB: Add Jak X Beta Trial to DB and a patch that makes it able to boot. (#2482)
  * GSdx: Add some missing crc ids.
* Thu Jun 14 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180613:
  * PCSX2: Update Scandinavian translations. (#2481)
* Mon Jun 11 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180611:
  * cdvdgigaherz:gtk: Simplify GUI dialog
  * cdvdgigaherz: Replace use of deprecated wstring_convert
  * cdvdgigaherz:windows: Adjust CD read success condition
  * cdvdgigaherz: Remove unused mode parameter/member variables
  * GSdx-d3d: Rearange PSSelector(GSDeviceDX.h).
  * GameDB: Moorhuhn Fun Kart 2008.
  * GSdx: Purge leftover SSX3 crc ids no longer needed.
* Sat Jun  9 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180609:
  * GSdx: Also update Tekken 5 ntsc-j crc hacks to work on progressive mode.
  * GSdx: CRC hacks for Tekken 5 NTSC-U should work on progressive mode as well now.
  * psxmode: move pgifInit() over to EE reset; start porting recent (later than ~2001) changes in CdRom.cpp, starting with labels; add a note on missing video timing recalculation when entering psxmode
* Fri Jun  8 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180608:
  * psxmode: actually apply the new iop / cd read timings; add seek delays that mimic real ones; altogether this at least fixes fmv playing way too quickly (music in Chrono Cross intro is fine now, for example)
* Wed Jun  6 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180606:
  * GameDB: Remove Rounding modes on Teen Titans
  * GameDB: Add gamefix to restore missing text in Teen Titans.
* Sat Jun  2 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180602:
  * GameDB: Add/adjust DOA2 Hardcore patch.
  * GameDB: Add EE patches for Spyro NB/EN.
  * GSdx: Purge Spyro NB /EN hw hack fixes.
* Fri Jun  1 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180531:
  * GSdx: Disable Alpha hack gui option on D3D9.
* Thu May 31 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180531:
  * cmake: Fix GSdx EGL build libX11-xcb linkage issue
* Wed May 30 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180530:
  * GSdx:Port better support of palette from GL to D3D10/11.
  * MFIFO: Refactor of some of the VIF/GIF MFIFO functionality. Centralised the MFIFO resume function which should have been separate anyway. Added some more memory address safeguards. Logging now makes a bit more sense to look at.
* Sun May 27 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180527:
  * GameDB: Clean up/reformat db a bit more.
  * GameDB: Rayman Revolution fixes + missing demo entry
* Sat May 26 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180526:
  * Previous fix for Eragon was incorrect. Game makes PATH3 busy then performs a reset, allowing VIF to continue, this is the fix I should have made ;)
  * PS1 mode: Adjustments to processor clock speed and CD read speed.  (#2447)
* Thu May 24 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180524:
  * Gamedb: Clean up db partially.
* Thu May 24 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180523:
  * Gamedb: Add Giffifohack gamefix to NFL Street 3.
* Wed May 23 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180522:
  * GSdx: Adjust Sky Gunner crc hack.
  * GSdx: Add some missing crc ids.
* Tue May 22 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180521:
  * VIF FIFO: Hacked the hack. Fixes Downtown Run.  Tested all known games that need the hack, they still work *phew*
* Mon May 21 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180521:
  * GSdx-OSD: Adjust messages.
* Mon May 21 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180521:
  * GSdx: Adjust Spyro New Beginning crc hack.
* Sun May 20 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180520:
  * GSdx: Update Spyro Hw fix/hack.
* Sat May 19 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180519:
  * GSdx: Adjust Sonic Unleashed crc hacks.
  * Fixed optimisation problem on branch in branch delay slot. Fixes Dropship - United Peace Force.  Props to MrCK1 for finding the issue.
* Wed May 16 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180516:
  * GSdx: Add a missing crc id for CrashNburn EU.
  * GameDB: Code cleanup/ Vampire Night EE Timing Hack removal/ Armored Core fixes
  * GSdx: Remove Hummer Badlands CRC Hack.
* Sat May 12 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180512:
  * common: Work around GCC8 _xgetbv bug
* Fri May 11 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180511:
  * GameDB: Scarface and Harry Potter COS Updates. (#2431)
  * GameDB: Update Dead or Alive 2 gamefix patch.
* Thu May 10 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180510:
  * [skip ci] GSDumpGui: Adjust copyright information.
* Wed May  9 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180509:
  * GSdx: Adjust crc hacks for Big Mutha Truckers.
* Wed May  9 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180509:
  * GSdx: Adjust crc hacks for Heavy Metal Thunder.
* Tue May  8 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180507:
  * GameDB: Add Prafull's Patch for Klonoa 2.
* Sun May  6 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180506:
  * gsdx: remove DirectCompute backend
  * common: Fix multiple _xgetbv() error on GCC 8
  * GSdx: Purge crc ids/games no longer needed.
* Sat May  5 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180505:
  * i10n: update mo files
* Sat May  5 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180505:
  * Gsdx: Remove Captain Tsubasa crc hacks.
  * GSdx: Adjust crc ids.
* Thu May  3 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180503:
  * GameDB: Add Harry Potter patch for the PAL version.
* Wed May  2 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180502:
  * GameDB: Minor info-alterations (#2379)
* Tue May  1 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180501:
  * GameDB: Add XgKickHack for Crash Twinsanity (NTSC-J).
* Sun Apr 29 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180429:
  * gsdx-legacy: Copy GSdx baseclasses changes
  * baseclasses: Move from unfree to 3rdparty
  * baseclasses|gsdx: Move code from baseclasses to GSdx
  * gsdx: Remove code that does nothing
* Sat Apr 28 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180428:
  * pcsx2: Remove theming support
* Fri Apr 27 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180427:
  * Gsdx: Adjust Front Mission 5 crc hacks.
* Thu Apr 26 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180426:
  * pcsx2: Fix potential return of uninitialised value
  * pcsx2: Use enums instead of hardcoded integer
* Wed Apr 25 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180424:
  * GSdx: Update D3D fbmask emulation on texture shuffle.
* Mon Apr 23 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180422:
  * GSdx: Add Sly 3 demos crc ids.
* Thu Apr 19 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180419:
  * GameDB: Add vuClampMode hack/remove eeClampMode hack for Pac-Man World Rally. Fixes bad geometry. This also replaces the EEClampMode hack in the NTSC-U release which didn't appear to do anything.
* Tue Apr 17 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180417:
  * PCSX2-GUI: 'About' Logo
* Mon Apr 16 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180416:
  * PCSX2-GUI
* Mon Apr 16 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180415:
  * Add missing names to About Box, removed duplicate, misc. formatting
  * GameDB: Add vuClampMode hack to Katamari/SkipMPEGHack to Arctic Thunder.
* Sun Apr 15 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180415:
  * GSdx-TC: Don't skip depth lookup on Jackie Chan Adv and SVC Chaos.
  * GSdx: Add some missing crc ids.
  * Update widescreen patches/cheats.
* Sat Apr 14 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180413:
  * Updated Russian translation (#2377)
* Thu Apr 12 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180411:
  * PCSX2: Update gamefix tooltip.
* Tue Apr 10 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180410:
  * GameDB: Revert Crash Tag Team Racing gamefix.
* Sat Apr  7 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180407:
  * GameDB: Add XgKickHack for Crash Twinsanity (NTSC-U)
* Tue Apr  3 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180403:
  * GSdx: Adjust Naruto series crc hacks
* Mon Apr  2 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180402:
  * Gsdx: Add some missing crc ids.
  * GSdx: Adjust CRC hacks.
* Sat Mar 31 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180331:
  * SPU2-X: Fix UI regression
* Wed Mar 28 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180327:
  * GameDB: Add Quake 3 Revolution patch.
  * GSdx: Add Quak3 Revolution to Automatic mipmapping.
  * GSdx: Adjust CRC hacks.
  * GSdx: Remove fbmask handle in GSRendererDX.
* Sat Mar 24 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180323:
  * GSdx-D3D: Texture and channel shuffle improvements.
* Thu Mar 22 2018 opensuse-packaging@opensuse.org
- Update to version 1.5.0~git20180322:
  * GSdx Adjust/Replace crc hack for Final Fight Streetwise.
  * GSdx: Add some missing crc ids.
* Tue Mar 20 2018 opensuse-packaging@opensuse.org
- Update to version 1.5.0~git20180320:
  * GameDB: Updates
* Mon Mar 19 2018 opensuse-packaging@opensuse.org
- Update to version 1.5.0~git20180319:
  * GSdx: Add Shox to Automatic Mipmapping
* Tue Mar 13 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180313:
  * GSdx: Cleanup hacks in GSRendererHW.
  * GSdx: Remove GT3/Concept CRC Hacks.
  * GSdx: Add/adjust CRC ids.
* Thu Mar  8 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180308:
  * PCSX2: Minor lingual correction on tooltip (#2328)
  * Gif: Allow flag setting for PRIM/REG transfers on 0 length packets. Fixes Reservoir Dogs
* Mon Mar  5 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180305:
  * Console Window: Reset the titlebar when the VM is shutdown.
  * GameDB: Add GIF FIFO hack for Spongebob SquarePants: Creature From the Krusty Krab (fixes bad graphics) [skip ci]
  * GSdx: Rename HW hacks drop list options.
* Sun Mar  4 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180304:
  * PCSX2: Remove the "DisableOutput" option. (#2298)
* Sat Mar  3 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180303:
  * gsdx: Remove inappropriate comment
  * GSdx-TC: Fix load size calculation in target update
* Fri Mar  2 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180302:
  * GSdx: GSCrc.cpp reformat comments and whitespaces.
  * GSdx: Add/adjust CRC ids.
* Wed Feb 28 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180228:
  * gui: Fix trace logging panel misc section behaviour
  * pcsx2: Fix Trace Logging enable/disable behaviour
  * gui: Fix apply button on Trace Logging dialog
  * utilities: Fix CheckedStaticBox behaviour
  * Fr translation update (#2270)
  * GameDB: Update Crash Tag Team Racing
  * GameDB: Fix for many games
  * More Relocations
  * Relocations
  * GameDB: Scarface
* Sun Feb 25 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180225:
  * GameDB: VU rounding fixes for Guitar Hero series and Hitman Contracts.
* Sat Feb 24 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180224:
  * Portuguese-BR translation update
* Thu Feb 22 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180222:
  * GSdx (OGL HW): Perform a texture shuffle when the address of the framebuffer and the texture are the same.
  * GSdx: Remove GT4/Tourist Trophy CRC hacks
  * Gsdx: Adjust Ikkitousen CRC hacks.
  * Final Fantasy X fix, Compat update
* Tue Feb 20 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180220:
  * Utilities: Fix subtraction operation function in FixedInt class (#2313)
* Tue Feb 13 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180213:
  * cmake: Improve wxWidgets and SDL linkage check
* Sun Feb 11 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180210:
  * PCSX2-Counters: Fix rounding of blank and render
  * Counters: Fix Hblank calculation for DVD videmodes
  * GameDB: Update Silent Hill 3
  * pcsx2: Fix string truncation on Windows
  * gsdx:d3d: Fix fbmask conversion on texture shuffle
  * cdvdgigaherz:windows: Refactor to use early returns
  * cdvdgigaherz:windows: Avoid unneeded DVD ioctls
  * GSdx: Adjust DBZ BT2 CRC hack and id, add R&C3 EU to Automatic Mipmap.
  * GSdx: Change Skipdraw Maximum limit value.
  * Resolve cases where GUI values are not updated when adjusting sliders with the scroll wheel.
  * Remove unused 'About Box' references on Linux and Windows from SPU2-X/CMakeLists, ect.
  * Make GUI more user-friendly by disabling some options when they aren't used.
  * Plugins: Move Xpad and USBqemu plugins to old plugins solution
  * pcsx2: Fix copy bytes patch command
  * PCSX2: Avoid SYSTEM.CNF error message in PSX mode (#2286)
  * PCSX2: Add configurable Cheats folder to Components Selectors.
  * cdvd: Fix writing of CD blockdumps
  * cdvd: Fix and switch to writing v2 format blockdumps
  * Gif: Don't set state on NOP packet. Fixes #2277
  * Portuguese-BR translation update
  * PCSX2: Memory card minor code improvements
  * PCSX2: Add keyboard shortcuts to memory card dialog right-click menu
  * PCSX2: Update PSX memory card file extension
  * PCSX2: Replace PSX memory card checkbox
  * GSDumpGUI: Update the GUI interface
  * gsdumpgui: s/GSDX/GSdx/
  * gsdumpgui: Improve renderer override handling
  * cmake: Remove old macro substitution workaround
* Sun Jan 14 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20180114:
  * Enhance "Assemble Opcode" to be pre-populated by existing instruction. (#2244)
  * GSdx: Disable Merge Sprite on native resolution.
  * SPU2-X: Prevent volume check from altering volume
  * GSdx: Add Dark Cloud CRCs to automatic mipmapping
  * GSdx: Merge CRC hacks of Wild Arms 4 and 5
  * cmake: Don't print a git describe error with shallow clones.
  * GSdx: Remove/move/merge CRC hacks.
  * GSdx: Move CRC hacks for Soul Calibur 2&3 to DX level.
  * PCSX2-WX: Display the video mode on titlebar
  * iop: Fix booting ELF files on a different drive
  * Fix mouse click focus in debugger near functions ending in a branch. (#2250)
  * Corrected MipsOpscodes table for unconditional branch. (#2247)
* Wed Jan  3 2018 pousaduarte@gmail.com
- Update to version 1.5.0~git20171228:
  * Portuguese-BR translation update (#2209)
  * GameDB: Fixes and compatibility status update (#2223)
* Thu Dec 21 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171220:
  * Italian translation update (#2155)
  * GameDB: Add proper rounding mode for Beyond Good and Evil v2 (#2214)
  * Gsdx: Tekken 5 Channel effect and CRC Hacks
  * GSdx: Add hidden option to disable Nvidia hack
  * Make PSX cards appear as Pocketstation devices. (#2208)
  * GameDB: Add proper rounding mode for Beyond Good and Evil (#2210)
* Tue Dec  5 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171202:
  * Flag XP as an unsupported OS.
* Fri Dec  1 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171130:
  * ci: Fix Travis CI build issues
* Thu Nov 30 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171128:
  * GSdx: Remove/move CRC hacks for Simpsons Game
  * GSdx: Extend support of "Preload Frame Data" for Direct3D.
  * pcsx2:gui: Display '&' properly in recent ISO list menu
* Sun Nov 26 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171124:
  * cdvdgigaherz: Always read 2352 bytes from CD sectors
  * cdvdgigaherz: Detect CD track mode correctly
  * Update PCSX2_FAQ.doc to reflect changes made on the PCSX2 Forum (#2087)
  * Updating Portuguese-BR translation
  * Translations: French
  * GSdx: Automatic HW Mipmapping option
  * GSdx: Rearrange HW Hacks
  * Updating Spanish translation
  * Swedish translation update
  * GSdx: Remove CRC hack for James Bond Everything or Nothing. Thes hack was used to avoid a VRAM spike, but isn't needed anymore.
* Fri Nov 17 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171114:
  * Add vuClampMode fix to EA Burnout titles.
  * GSdx: Add/move CRC hacks for Street Fighter EX3
* Sun Nov 12 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171111:
  * GSdx-Capture: Grayout configure button for codecs
  * GSdx-Capture: Format event commands in switch-case
  * GSdx: Add CPU Frame buffer Conversion Hack
* Wed Nov  1 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171031:
  * Update SoundTouch lib to v2.0.0
* Sun Oct 29 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171029:
  * pcsx2|common|gsnull: Remove GSprintf API
* Sun Oct 15 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171014:
  * ci: Update Travis CI and AppVeyor configurations
  * cdvdgigaherz: Fix Q subchannel relative offset calculation
  * PS2-HW: Remove address of non-existent registers
  * windows: Fix Devel solution configuration
* Thu Oct 12 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20171010:
  * PS2-HW: Fix DMA channel register addresses
  * Add clear list option to ISO Selector
* Fri Sep 22 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170917:
  * Allow PSX memcard creation, dynamic SIO delay type.
* Sat Sep  9 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170908:
  * PCSX2-GUI: Logo Update (Wider image)
  * gsdx: Prefix std:: to string and to_string
  * gsdx: Remove hash_{map,set} macros
  * gsdx: Prefix std:: to vector
  * gsdx: Prefix std:: to list
  * gdsx: Prefix std:: to map
  * gsdx: Prefix std:: to min and max
  * gsdx: Prefix std:: to shared_ptr
  * gsdx: Prefix std:: to ostringstream, pair, codecvt*
  * gsdx: Remove "using namespace std"
* Thu Sep  7 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170906:
  * GSdx-ogl: Fix GSdx crashing on Intel igpus
  * GSdx - dx9: Edit Alpha Correction (FBA) tooltip.
  * GSdx-ogl:
* Fri Sep  1 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170831:
  * ci: Fix Travis CI
  * gsdx:ogl: Call swap interval function on rendering thread
  * pcsx2: Apply vsync changes immediately on settings change
  * pcsx2: Fix inconsistent framelimiter/vsync interaction
  * lilypad: Fix Lock Direction/Input/Both features
  * GSdx-Windows: Grey out OSD and Shader Configuration
* Wed Aug 30 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170830:
  * GSdx GSDevice11: Fix unsigned warning under VS2015 with DEBUG build enabled.
  * GSdx GSCodeBuffer: std::vector instead of std::list, to speedup linear scan. Using range loop on destruction.
  * GSdx GSLocalMemory: Reserve space required in the std::vector before adding elements to it.
  * GSdx GSDirtyRect: std::vector instead of std::list, to speedup linear scan. Improved const-ness. Using range loop.
  * GSdx GSFastList: Introducing the custom container template class.
  * GSdx GSTextureCacheSW: Ported erase iterator trick. Using FastList instead of std::list. Using range loops. Using more efficient erase pattern.
  * GSdx GSDevice: Using FastList instead of std::list. Using range loops (correctly). Using auto instead of declaring iterator type.
  * GSdx GSTextureCache: Using FastList instead of std::list. Various other improvements. Using range loops where possible (correctly). Using auto where possible (minimize code changes whenever it's decided to change back to a std container). Use more efficient erase pattern (where possible). Minor code tweaks.
* Sun Aug 27 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170825:
  * GSdx-D3D11: Avoid undefined behavior in swapchain
* Wed Aug 16 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170816:
  * GSdx: Add missing CRC for GT3
* Tue Aug 15 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170814:
  * Update German Translation
  * small updates
  * small update
  * small update
  * a few corrections
  * revert kapitalized personal pronouns
  * glsl: extension must be declared first
  * glsl: miss color of SSO interface
  * correction
  * correction
  * small update
* Fri Aug 11 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170810:
  * onepad: fallback on 2nd gamepad for the 2nd player
  * onepad: print a more accurate message when only a single pad is detected
* Thu Aug 10 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170810:
  * gsdx ogl: factorize common context init code
  * gsdx ogl: factorize SetVSync
  * gsdx ogl: test adaptive/late vsync driver support
  * core: add a getter for the vsync option
  * pcsx2 gui: uses a combo box for Vsync
  * Update Translations (#2029)
  * PCSX2-WX: Force disable MTVU hack on safest preset
  * PCSX2-Git: Minor changes in issue template file
  * Add Horipad One config
* Mon Jul 31 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170729:
  * onepad: add a first time wizard to notify that plugin auto-map the Gamepad/Joystick
  * Update GSCrc.cpp (#2018)
  * GSdx-Windows: Fix Shadeboost text bug
  * lilypad: Fix button detection issue in Kung Fu Panda
  * PCSX2-Counters: Fix tracking of scalar limit
  * GSdx: Adjust CRC for DBZ BT3
  * GSdx: Add missing CRC for Tomb Raider Underworld
* Mon Jul 17 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170713:
  * GSdx: Rework framebuffer height calculation
* Thu Jul 13 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170712:
  * gsdx ogl: handle float integral coordinate for depth sampling
  * glsl: reduce geometry shader complexity
  * PCSX2-WX: Add restore defaults to GS panel
  * PCSX2-WX: Revert titlebar update behavior on Windows
* Tue Jul  4 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170703:
  * cmake: Fix NetBSD compilation
  * cs_CZ update
  * GSdx-ogl: Printing console messages v2 (#1954)
  * core: add hidden option EnableVsyncWindowFlag to add the WS_POPUP flag
  * gsdx: remove the unused GSsetFrameLimit API
  * gsdx: store vsync state into an integer
  * i10n: upload cs_CZ mo binary files
  * onepad: Add platform:Linux on game db entries that miss it
  * gsdx:d3d11: Fix sprite geometry shader
  * Added Danish mo-files.
  * GameDB
  * i10n: upload da_DK precompiled mo file
* Fri Jun 30 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170630:
  * cmake: blacklist GCC 7.0 and GCC 7.1 (based on a small testcase)
  * GSdx: Cleanup warnings on MSVC
  * GSdx: Remove/move DBZ:BT3 CRC
  * GameDB: Add fixes to various games (#1977)
* Sat Jun 24 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170623:
  * ci: Fix 32-bit Travis CI builds
* Tue Jun 20 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170619:
  * PCSX2-WX: Increment max ISO count in recent ISO list
  * PCSX2-WX: Add "Always ask when booting" option
* Tue Jun 13 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170613:
  * gsdx:d3d11: Fix incorrect geometry shader use
* Fri Jun  9 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170609:
  * Add Danish translation
* Mon Jun  5 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170605:
  * 3rdparty: Add xz submodule
  * 3rdparty:xz: Add project and config file
  * gsdx: Use std::vector for xz dump output buffer
  * windows: Link GSdx to liblzma (xz)
  * unix: Remove LZMA_SUPPORTED define
  * gsdx: Fix GS dump readback EOF handling
  * gsdx: windows: Port xz dump readback
  * GSdx-OGL: Extend ICO workaround to PAL videomode
  * GSdx-HW: Revamp buffer size calculation
  * GSdx-HW: Move scaling code to separate subroutine
  * gsdx: Fix variable initialisation issue
* Thu May 25 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170524:
  * GSdx: Implement SYNCV register bitfields
* Tue May 23 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170523:
  * onepad: Remove use of "using namespace std"
* Mon May 22 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170521:
  * linux: requires liblzma (xz) to build GSdx
  * gsdx: dump gsdump in xz format directly
* Sun May 21 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170521:
  * gsdx: defer init of GSUtil global object
* Tue May 16 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170516:
  * common: workaround to start ASAN with recent glibc
  * Add installer icon, update copyright and build instructions for NSIS 3.0.
  * Implement version detection for previous installs, separate savestates/memcard categories in the uninstaller. Cleanup scripts and misc. tweaks.
  * Remove unused SVN templates and condense installer files. Reduced compile errors by removing output folder dependency.
  * Block installation on XP/fix an uninstaller regression and add ManifestDPIAware to the installer. Remove NSIS dirs from .gitignore.
  * Reformat version detection, move null plugins, force remove folder in uninstaller.
  * Check/Install DirectX redistributables on Win8.1 and older (so as long as they have admin privileges). Removed SSSE3 and AVX references from build instructions.
  * Split portable/pre-install and full installer into own scripts. Move shared definitions to their own files to reduce code duplication.
  * Added pre-install dialog, updated build instructions, fix RegKey in uninstaller, automatically backup old configuration folder, misc. changes.
* Mon May 15 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170513:
  * Cmake: what should have been the previous commit
  * common: use = default instead of trivial constructor/destructor
  * core/gui: use = default instead of trivial constructor/destructor
  * core: use = default instead of trivial constructor/destructor
  * core: use = default instead of trivial copy constructor
  * gsdx: use = default instead of trivial constructor/destructor
  * common: remove throw specifier on destructor
  * common: use = default instead of trivial destructor
  * core: remove throw specifier on destructor
  * core: use = default for trivial destructor
  * core: remove noexcept on destructor
  * pcsx2|common: replace throw() by noexcept
  * gsdx linux: port to latest GTK3 API
* Fri May 12 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170511:
  * onepad: remove useless code
  * onepad: be sure m_unique_id is set even in case of early return
  * gsdx: only print once OpenGL status message
  * cmake: better gcc + gsdx integration
* Thu May 11 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170511:
  * Allow building the player with the legacy GSdx.
  * GSFrame: Update title only after rendering starts
  * Counters: Update videomode enum with proper prefix
* Mon May  8 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170508:
  * GSDX: Add missing grayouts to Shadeboost options
  * GSDX: Remove redundant parenthesis from combobox text
  * cmake: search /usr/bin/wx-config32 (for arch users...)
* Fri May  5 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170503:
  * onepad: s/set_keyboad_key/set_keyboard_key/
  * onepad: drop useless goto statement
  * onepad: allow to save/reload SDL2 mapping from OnePAD2.ini file
  * onepad: remove dead code
  * onepad: replace key_status pointer by g_key_status object
  * onepad: replace conf pointer by g_conf object
  * onepad: create a LUT for the pad key => SDL key mapping
  * onepad: move KeyName in the dialog and remove the now useless dialog.h
* Wed May  3 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170503:
  * build.sh: avoid duplicate on clang-tidy analysis
  * common: add make_unique for C++11
  * modernize: use std::make_unique instead of std::unique_ptr
* Tue May  2 2017 pousaduarte@gmail.com
- Update to version 1.5.0~20170502:
  * onepad: add DUALSHOCK4 USB Wireless Adapator mapping
* Mon May  1 2017 pousaduarte@gmail.com
- Update to version 1.5.0~20170430:
  * onepad: move an ok button to the right corner
  * gsdx: call XInitThread on Linux dump replay
  * gsdx: Fix uptr size on Windows x64 build
  * Revert "pcsx2: call XInitThreads at init"
  * gsdx egl: rewrite the EGL implementation
  * spu2x: comment unused variable
  * pcsx2: remove unused variable
  * psx|spu2x|gsdx: shift negative value is undefined in C standard
  * gif: avoid (wrong) uninitialized warning
  * svu: cast variable to int to avoid unsigned vs int comparison
  * spu2-x: Remove outdated website text file
  * pcsx2: Remove unnecessary aMax/aMin macros
* Fri Apr 28 2017 pousaduarte@gmail.com
- Update to version 1.5.0:
  * spu2-x: Combine XAudio2 2.7/2.8+ code into an inline file
  * spu2-x:xaudio2: Simplify XAudio2Error exception
  * spu2-x:xaudio2: Improve cleanup after an exception
  * spu2-x:xaudio2: Use unique_ptr
  * spu2-x:xaudio2: Comment stuff to investigate
  * cmake: create the macro add_custom_glib_res to handle resources
  * cmake: reindent onepad/CMakeLists.txt with space
  * onepad: add a game controller db resource
  * onepad: use range loop and vector of unique_ptr to manage the joystick
  * onepad: properly indent comments
  * onepad: drop hacks/options for DualShock3
  * onepad: remove SDL1 manual detection code path
  * onepad: move enum first in .h file
  * onepad: plug SDL2 API game controller
  * onepad: use external resource to support more joysticks
  * onepad: Move init/destroy code to constructor/destructor
  * onepad: drop the pad if an error was detected
  * onepad: add hot-plugging support
  * onepad: use range loop for hash iteration
  * onepad: add an unique identifier
  * onepad: plug uid instead of the index
  * onepad: add a GUI list box to select joypad based on UID
  * onepad: replace pthred/queue with std::mutex/mt_queue
  * onepad: remove autorepeat deadcode
  * onepad: clean the gamepad/joystick interface
* Fri Apr 28 2017 pousaduarte@gmail.com
- Update to version 1.5.0dev~20170427:
  * GSdx: Move/add GT4 CRC
* Thu Apr 27 2017 pousaduarte@gmail.com
- Update to version 1.5.0dev~20170426:
  * pcsx2: call XInitThreads at init
* Mon Apr 24 2017 pousaduarte@gmail.com
- Update to version 1.5.0dev~20170423:
  * zh_CN po files update
  * zh_CN mo files update
* Sun Apr 23 2017 pousaduarte@gmail.com
- Update to version 1.5.0dev~20170423:
  * gsdx: fix EGL build
  * gsdx: don't request a depth buffer on the window
  * cmake: update "check these lib..." strings
* Sat Apr 22 2017 pousaduarte@gmail.com
- Update to version 1.5.0dev~20170421:
  * pcsx2: Fix booting ISO from commandline
* Fri Apr 21 2017 pousaduarte@gmail.com
- Update to version 1.5.0dev~20170421:
  * PCSX2-Counters: Detect DVD variant videomodes
  * gsdx sw: always enable the gs memory wrapping emulation
  * pcsx2: Fix autorun when commandline and current CDVD options differ
  * pcsx2: Fix "nodisc" commandline option
  * pcsx2: Avoid clearing current ISO when not autorunning with an ISO
  * GSdx: Move Resident Evil 4 and The Getaway series CRC hacks
  * GSdx: Remove Dirge Of Cerberus CRC hack
* Thu Apr 20 2017 pousaduarte@gmail.com
- Update to version 1.5.0dev~20170419:
  * onepad: create a legacy version for SDL1
* Wed Apr 19 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170419:
  * Align functions to up to 16 bytes in the function scanner
* Mon Apr 17 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170417:
  * ci: Initialise git submodules in AppVeyor
* Sat Apr 15 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170415:
  * Make memory view row size configurable, store it and "Align window to row size" in settings
* Fri Apr 14 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170414:
  * common: drop pthread TLS emulation
* Thu Apr 13 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170413:
  * linux: mesa full steam ahead !
  * common: Replace __threadlocal with C++11 thread_local
* Wed Apr 12 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170412:
  * gsdx: use vector of char as shader container
  * gsdx linux: implement GSdxApp::LoadResource based on g_resource
  * gsdx: always NULL terminate resources on Windows
  * gsdx ogl: use load resource to load shader
  * gsdx: add GSmkdir for windows based on CreateDirectory
  * gsdx: add GStempdir wrapper to get a tempory directory
* Tue Apr 11 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170411:
  * cdvdgigaherz: Avoid LL after date in library name string
* Sun Apr  9 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170409:
  * pcsx2: Remove unused variables
  * gsdx ogl: remove useless glx/egl context print
* Sat Apr  8 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170408:
  * gsdx linux gui: reduce height on/for small screen
  * gsdx linux gui: align gui with wndows (tooltip + checkbox)
  * gsdx ogl: Deleted objects are automatically unbound/unmapped
  * remove an old merge conflict file (that souldn't have been commited)
* Thu Apr  6 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170406:
  * GameDB: Add GT3 memcard filter
  * GSdx ogl sw: Move GL_ARB_copy_image to optional
* Wed Apr  5 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170404:
  * gsdx sw: Update comment on the GCC bug
* Tue Apr  4 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170404:
  * gsdx ogl: reduce requirement for SW renderer
* Sat Apr  1 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170401:
  * GameIndex: minor update
  * gsdx: cpu detection take 3! Don't use 64 bits type in Xbyak::Cpu
  * GSdx: Memory Wrapping Windows port
  * GSdx: Direct3D port of HPO special/V2
  * GSdx: Main & Hacks window update
  * GSdx: Shader & OSD window update
  * GSdx: Add Windows GUI for split texture filtering option
  * GSdx: Unscale Point and Line Direct3D11 port
  * GSdx: Add merge sprite hack to GSdx hacks dialog
  * gsdx: workaround AVX2 generated code by GCC
* Thu Mar 30 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170330:
  * GSdx-PCRTC: Minor modification to NTSC saturation
  * gsdx: Avoid const strings in header file
* Wed Mar 29 2017 pousaduarte@gmail.com
- Update to version 20170328~v1.5.0dev:
  * gsdx:windows: Fix console output when replaying dumps
  * lilypad: Use l length modifier for wide character string
  * Swedish translation update.
  * Add crc hack for project metafalica
  * GSdx ogl: SSO Workaround for AMD buggy drivers (#1858)
  * gsdx: Move renderer config loading from GSOpen2 to _GSOpen
  * gsdx: Store the current renderer in GSdxApp
  * gsdx: Improve OpenGL HW renderer checks
  * gsdx: Add template version of GetConfig
  * gsdx: Add an automatic CRC hack level
* Mon Feb 13 2017 pousaduarte@gmail.com
- Enforce XDG specification for configuration files
* Sat Feb 11 2017 pousaduarte@gmail.com
- Update to version 1.5.0~git20170211:
  * pcsx2: set the size of the vector in the constructor
  * gsdx ogl: allow to start without GL_ARB_texture_barrier
  * gsdx ogl: drop fallback of GL_ARB_clear_texture
  * cmake: add an option to enable openCL
  * gsdx opencl: warning+compilation fixes
  * gsdx ogl: add a texture barrier when target is read back
  * gsdx sw: init completely m_scanline buffer
  * gsdx wgl: retry to create a context without advance flag
  * GameIndex.dbf: Removed Shin Megami Tensei Digital Devil Saga series EE timing hack
* Wed Jan 11 2017 guoyunhebrave@gmail.com
- Drop openSUSE-release BuildRequires to build on openSUSE Leap 42.2 i586
* Tue Jan 10 2017 guoyunhebrave@gmail.com
- version 1.4.0+git20170110
  * [New Feature] Debugger by Kingcom
  * [New Feature] Folder memory cards by AdmiralCurtiss
  * [New Feature] EE Overclock by ssakash and Blyss Sarania
  * [New Feature] Support for loading Gzip and CSO compressed ISO's by Avih and
    Unknown W.Brackets
  * [New Feature] Per channel volume adjustment by gigaherz
  * [Enhancement] Configurable template on GSFrame titlebar by Avih
  * [Enhancement] Revamped Core and GSDX plugin dialogs by Turtleli, Gregory and
    ssakash
  * [Bug-Fix] Recompiler Improvements and Core Refactors by Refraction, ssakash
    and Gregory
  * [Bug-Fix] Programmable blending to reproduce GS blending unit output by Gregory
  * [Bug-Fix] Improved CRTC output size handling by ssakash and .r5
  * [Bug-Fix] Software renderer improvements by Gabest and Gregory
  * [Bug-Fix] Accurate destination alpha testing by Gregory
  * [Bug-Fix] Improved read of depth / color by Gregory
  * [Bug-Fix] Time Stretcher: Improvements to tempo adjustments by Avih
  * GIF: Better Handling for Finish Interrupt request signal by Refraction
  * MicroVU: General Improvements by ssakash and Refraction
  * SIF: Limit/Mask transfer size to 1mb-16bytes by Refraction
  * VIF: Better handling of IRQ and MFIFO Timing improvements by Refraction
  * EE Interpreter: Improved TLB miss exception handling by Gregory
  * See http://pcsx2.net/273-1-4-0-release-end-2015-report.html
- Drop patches
  * pcsx2-cdvdiso-fopen64.patch
  * pcsx2-cdvdisoefp-header.patch
  * pcsx2-optflags.patch
  * pcsx2-spu2null-overflow.patch
